# PyPhot

A Python library for the simulation of optical fiber transmission, characterized by the ability of running on both CPU and GPU to gain powerful acceleration.

## Get started

```shell
# Install PyPhot library
pip3 install phot

# Run example
python3 example.py
```

The Python file **example.py** under the root directory showing how to use our API (for PyPhotEngine). Please read it carefully.

## Development Document

For developers, check [this](docs/dev-doc.md).
